@@ -6,7 +6,7 @@ use strict;
 use 5.010;
 
 use Bio::Grid::Run::SGE::Log::Analysis;
-use Data::Printer;
+use Data::Printer rc_file => '';
 
 my $job_name = shift;
 my $la       = Bio::Grid::Run::SGE::Log::Analysis->new(
