@@ -15,14 +15,14 @@ use Bio::Grid::Run::SGE::Iterator;
 use Bio::Grid::Run::SGE::Util qw/my_glob my_sys expand_path my_mkdir expand_path_rel/;
 use Cwd qw/fastcwd/;
 use Clone qw/clone/;
-use Data::Printer colored => 1, use_prototypes => 0;
+use Data::Printer colored => 1, use_prototypes => 0, rc_file => '';
 use Bio::Gonzales::Util::Cerial;
 use Capture::Tiny 'capture';
 use Config;
 use FindBinNew qw($Bin $Script);
 FindBinNew::again();
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 has 'cmd' => (
   is       => 'rw',
