@@ -12,7 +12,7 @@ use Bio::Grid::Run::SGE::Iterator;
 use Bio::Grid::Run::SGE::Util qw/my_glob my_sys expand_path my_mkdir expand_path_rel/;
 use Cwd;
 use Clone qw/clone/;
-use Data::Printer colored => 1, use_prototypes => 0;
+use Data::Printer colored => 1, use_prototypes => 0, rc_file => '';
 use Bio::Gonzales::Util::Cerial;
 
 use Config;
