@@ -42,4 +42,4 @@ run_job(
     }
 );
 
-exit;
+1;
