@@ -26,4 +26,4 @@ run_job(
     }
 );
 
-exit;
+1;
