@@ -36,8 +36,8 @@ sub do_worker_stuff {
             print $res_fh uc($_) . " AGCTNNN\n";
         }
     }
-    close $res_fh;
-    close $seq_fh;
+    $res_fh->close;
+    $seq_fh->close;
     if ( $task_id % 2 == 0 ) {
         return my_sys_non_fatal("cp $seq_file $result_prefix.orig");
     } else {
